@@ -1,6 +1,10 @@
 #!perl -wT
 # Copyright Dominique Quatravaux 2006 - Licensed under the same terms as Perl itself
 
+use strict;
+use warnings;
+use 5.006; # "our" keyword
+
 =head1 NAME
 
 My::Module::Build - Helper for releasing my (DOMQ's) code to CPAN
@@ -893,12 +897,14 @@ sub _process_options {
     my $walk_isa; $walk_isa = sub {
         my ($class, $seenref, $resultref) = @_;
         return if $seenref->{$class}++;
-        no strict "refs";
+        my $symtab = do { no strict "refs"; \%{"${class}::"}; };
         push @$resultref, grep {
-            my $meth = *{${"${class}::"}{$_}}{CODE};
-            defined($meth) && $declared_options{overload::StrVal($meth)};
-        } (keys %{"${class}::"});
+            my $symbol = $symtab->{$_};
+            ref(\$symbol) eq "GLOB" && defined(*{$symbol}{CODE}) &&
+              $declared_options{overload::StrVal(*{$symbol}{CODE})};
+        } (keys %$symtab);
 
+        no strict "refs";
         $walk_isa->($_, $seenref, $resultref) foreach @{"${class}::ISA"};
     };
     my @alloptions; $walk_isa->( (ref($self) or $self), {}, \@alloptions);
